import { type Readable, type Updater } from 'svelte/store';
import { type z } from 'zod';
interface ICreateFormOptions<T> {
    /**
     * The initial value of fields in the form.
     */
    initialValue?: Partial<T>;
    /** Should return nothing, or an error message */
    onSubmit?: (v: T) => Promise<void | string>;
    /**
     * Debounce the value update (ms). Passing 0 to disable debounce
     * @default 0
     */
    debounceDelay?: number;
}
export declare class ZodFormStore<A extends z.ZodRawShape, O = A> {
    readonly model: Readable<O>;
    fields: {
        [K in keyof O]: ZodFieldStore<K, A, O>;
    };
    triggerSubmit: () => void;
    reset: () => void;
    submitting: Readable<boolean>;
    errors: Readable<string[]>;
    valid: Readable<boolean>;
    constructor(schema: z.ZodObject<A, z.UnknownKeysParam, z.ZodTypeAny, O>, options?: ICreateFormOptions<O>);
}
export declare class ZodFieldStore<K extends keyof O, A extends z.ZodRawShape, O = A> {
    name: K;
    value: Readable<O[K]>;
    touched: Readable<boolean>;
    dirty: Readable<boolean>;
    error: Readable<string>;
    handleUpdate: (updater: Updater<O[K]>) => void;
    handleChange: (e: unknown) => void;
    handleBlur: () => void;
    reset: () => void;
    constructor(parentSchema: z.ZodObject<A, z.UnknownKeysParam, z.ZodTypeAny, O>, name: K, initialValue?: unknown, ms?: number);
}
export {};
